==> BestCrypt-2.0.7.tar.gz: BestCrypt-2.0.7/certificate/CertificateLib/symmetricAlgs/symmetricAlgs.cpp <==
#include "../publicKeyAlgs/Power/Windefs.h"
#include "../PGPPkts/pktdefs.h"
#include "../PGPPkts/Packets.h"
#include "symmetricAlgs.h"
#include "cSymAlg.h"
#include "cAlgDummy.h"
#include "cAlg3des.h"
#include "cAlgIdea.h"
#include "cAlgBfish.h"
#include "cAlgCast.h"
#include "cAlgGOST.h"
#include "cAlgTFish.h"
#include "cAlgRIJN.h"
#include "cAlgSerpent.h"
#include "cAlgDes.h"

typedef cSymAlg *typeCreateAlg( BYTE *keyBf, int keyBfSize );
typedef int typeGetKeySize( int *pMax/* = NULL */ );
typedef int typeGetBlockSize();


//
//	9.2. Symmetric Key Algorithms
//
//	ID           Algorithm
//	--           ---------
//	0          - Plaintext or unencrypted data
//	1          - IDEA [IDEA]
//	2          - Triple-DES (DES-EDE, as per spec - 168 bit key derived from 192)
//	3          - CAST5 (128 bit key, as per RFC 2144)
//	4          - Blowfish (128 bit key, 16 rounds) [BLOWFISH]
//	5          - SAFER-SK128 (13 rounds) [SAFER]
//	9          - AES-256 ( RIJN )
//

struct sSymAlgTabItem { int algID; typeCreateAlg *createFunc; typeGetKeySize *getKeySizeFunc; typeGetBlockSize *getBlockSizeFunc; }
	algTbl[] = 
		{
			{ pgpsaPlaintext,	cAlgDummy	::createAlg, cAlgDummy		::getKeySize, cAlgDummy		::getBlockSize },
			{ pgpsaIDEA,		cAlgIdea	::createAlg, cAlgIdea		::getKeySize, cAlgIdea		::getBlockSize },
			{ pgpsaTripleDES,	cAlg3des	::createAlg, cAlg3des		::getKeySize, cAlg3des		::getBlockSize },
			{ pgpsaCAST5,		cAlgCast	::createAlg, cAlgCast		::getKeySize, cAlgCast		::getBlockSize },
			{ pgpsaBlowfish,	cAlgBfish	::createAlg, cAlgBfish		::getKeySize, cAlgBfish		::getBlockSize },
			{ bcsaBFish,		cAlgBfish256::createAlg, cAlgBfish256	::getKeySize, cAlgBfish256	::getBlockSize },
			{ bcsaBFish448,		cAlgBfish448::createAlg, cAlgBfish448	::getKeySize, cAlgBfish448	::getBlockSize },
			{ bcsaTFISH,		cAlgTFish	::createAlg, cAlgTFish		::getKeySize, cAlgTFish		::getBlockSize },
			{ pgpsaTFISH,		cAlgTFish	::createAlg, cAlgTFish		::getKeySize, cAlgTFish		::getBlockSize },
			{ bcsaGOST,			cAlgGOST	::createAlg, cAlgGOST		::getKeySize, cAlgGOST		::getBlockSize },
			{ bcsaRIJN,			cAlgRIJN	::createAlg, cAlgRIJN		::getKeySize, cAlgRIJN		::getBlockSize },
			{ pgpsaAES_128,		cAlgAES128	::createAlg, cAlgAES128		::getKeySize, cAlgAES128	::getBlockSize },
			{ pgpsaAES_192,		cAlgAES192	::createAlg, cAlgAES192		::getKeySize, cAlgAES192	::getBlockSize },
			{ pgpsaAES_256,		cAlgRIJN	::createAlg, cAlgRIJN		::getKeySize, cAlgRIJN		::getBlockSize },
			{ bcsaSERP,			cAlgSerpent	::createAlg, cAlgSerpent	::getKeySize, cAlgSerpent	::getBlockSize },
			{ bcsaDES,			cAlgDes		::createAlg, cAlgDes		::getKeySize, cAlgDes		::getBlockSize },
		};

//
//	See enums at pktdefs.h
//
static int IDsTab[] = {
	pgpsaIDEA,
	pgpsaTripleDES,
	pgpsaCAST5,
	pgpsaBlowfish,
//	pgpsaAES_256,
	bcsaBFish,
	bcsaBFish448,
	bcsaTFISH,
	bcsaGOST,
	bcsaRIJN,
	bcsaSERP,
	pgpsaPlaintext
};

const char *sa_getSymmetricAlgName( BYTE algID )
{
	if ( algID < bcsaMinAlgID )
		return PKT_GetSymmetricAlgName( algID );

	switch( algID )
	{
		case bcsaBFish		: return "Blowfish 256";
		case bcsaBFish448	: return "Blowfish 448";
		case bcsaTFISH		: return cAlgTFish	::getDisplayName(); //"TWOFISH";
		case bcsaGOST		: return cAlgGOST	::getDisplayName(); // "GOST";
		case bcsaRIJN		: return cAlgRIJN	::getDisplayName(); //"RIJNDAEL";
		case bcsaSERP		: return cAlgSerpent::getDisplayName();
		case bcsaDES		: return cAlgDes	::getDisplayName();
		default : return NULL;
	}
}

int sa_getIDsOfAvailableAlgAlgorithms( int *pIDsCount, int **ppIDsTab )
{
	if ( pIDsCount != NULL )
		*pIDsCount = sizeof( IDsTab ) / sizeof( *IDsTab );

	if ( ppIDsTab != NULL )
		*ppIDsTab = IDsTab;

	return sae_ok;
}

int sa_createAlgorithm( HSA *pHSA, int algID, BYTE *keyBuff, int keyBuffSize )
{
	int q = sizeof( algTbl ) / sizeof( algTbl[0] );

	while ( q-- )
	{
		if ( algTbl[q].algID == algID )
		{
			*pHSA = algTbl[q].createFunc( keyBuff, keyBuffSize );
			return sae_ok;
		}
	}

	return sae_invalidAlgorithmID;
}

int sa_getKeySize( int algID, int *pMax )
{
	int q = sizeof( algTbl ) / sizeof( algTbl[0] );

	while ( q-- )
	{
		if ( algTbl[q].algID == algID )
			return algTbl[q].getKeySizeFunc( pMax );
	}

	return 0;
}

int sa_getBlockSize( int algID )
{
	int q = sizeof( algTbl ) / sizeof( algTbl[0] );

	while ( q-- )
	{
		if ( algTbl[q].algID == algID )
			return algTbl[q].getBlockSizeFunc();
	}

	return 0;
}

bool sa_isValidID( int algID )
{
	return ( sa_getBlockSize( algID ) != 0 ) ||
			( algID == pgpsaPlaintext );
}


int sa_encrypt( cSymAlg *sa, BYTE *outBf, const BYTE *inBf, int bfSize ) { return sa->encryptECB( inBf, outBf, bfSize ); }
int sa_decrypt( cSymAlg *sa, BYTE *outBf, const BYTE *inBf, int bfSize ) { return sa->decryptECB( inBf, outBf, bfSize ); }

//
// Switch on BestCrypt driver CBC mode compatibility.
//
void sa_setBCDriverCompatible( cSymAlg *sa, bool bSet ) { sa->setBCDriverCompatible( bSet ); }

int sa_encryptCBC( cSymAlg *sa, const BYTE *sync, BYTE *outBf, const BYTE *inBf, int bfSize ) { return sa->m_encryptCBC( sa, sync, inBf, outBf, bfSize ); }
int sa_decryptCBC( cSymAlg *sa, const BYTE *sync, BYTE *outBf, const BYTE *inBf, int bfSize ) { return sa->m_decryptCBC( sa, sync, inBf, outBf, bfSize ); }

int sa_initCFB( cSymAlg *sa, const BYTE *iv )	{ return sa->initCFB( iv ); }
int sa_syncCFB( cSymAlg *sa )					{ return sa->syncCFB();		}

int sa_encryptCFB( cSymAlg *sa, BYTE *outBf, const BYTE *inBf, int bfSize ) { return sa->encryptCFB( inBf, outBf, bfSize ); }
int sa_decryptCFB( cSymAlg *sa, BYTE *outBf, const BYTE *inBf, int bfSize ) { return sa->decryptCFB( inBf, outBf, bfSize ); }

void sa_free( cSymAlg *sa ) { delete sa; }

int sa_getBlockSize( cSymAlg *sa ) 
{
	int blockSize;
	int keySize;

	if (!sa->getAlgConstants( &blockSize, &keySize ))
		return 0;

	return blockSize;
}

==> BestCrypt-2.0.12.tar.gz: BestCrypt-2.0.12/certificate/CertificateLib/symmetricAlgs/symmetricAlgs.cpp <==
#include "../publicKeyAlgs/Power/Windefs.h"
#include "../PGPPkts/pktdefs.h"
#include "../PGPPkts/Packets.h"
#include "symmetricAlgs.h"
#include "cSymAlg.h"
#include "cAlgDummy.h"
#include "cAlg3des.h"
#include "cAlgIdea.h"
#include "cAlgBfish.h"
#include "cAlgCast.h"
#include "cAlgGOST.h"
#include "cAlgTFish.h"
#include "cAlgRIJN.h"
#include "cAlgSerpent.h"
#include "cAlgDes.h"
#include "cAlgRC2.h"

typedef cSymAlg *typeCreateAlg( BYTE *keyBf, int keyBfSize );
typedef int typeGetKeySize( int *pMax/* = NULL */ );
typedef int typeGetBlockSize();


//
//	9.2. Symmetric Key Algorithms
//
//	ID           Algorithm
//	--           ---------
//	0          - Plaintext or unencrypted data
//	1          - IDEA [IDEA]
//	2          - Triple-DES (DES-EDE, as per spec - 168 bit key derived from 192)
//	3          - CAST5 (128 bit key, as per RFC 2144)
//	4          - Blowfish (128 bit key, 16 rounds) [BLOWFISH]
//	5          - SAFER-SK128 (13 rounds) [SAFER]
//	9          - AES-256 ( RIJN )
//

struct sSymAlgTabItem { int algID; typeCreateAlg *createFunc; typeGetKeySize *getKeySizeFunc; typeGetBlockSize *getBlockSizeFunc; }
	algTbl[] = 
		{
			{ pgpsaPlaintext,	cAlgDummy		::createAlg, cAlgDummy		::getKeySize, cAlgDummy		::getBlockSize },
			{ pgpsaIDEA,		cAlgIdea		::createAlg, cAlgIdea		::getKeySize, cAlgIdea		::getBlockSize },
			{ pgpsaTripleDES,	cAlg3des		::createAlg, cAlg3des		::getKeySize, cAlg3des		::getBlockSize },
			{ pgpsaCAST5,		cAlgCast		::createAlg, cAlgCast		::getKeySize, cAlgCast		::getBlockSize },
			{ pgpsaBlowfish,	cAlgBfish		::createAlg, cAlgBfish		::getKeySize, cAlgBfish		::getBlockSize },
			{ bcsaBFish,		cAlgBfish256	::createAlg, cAlgBfish256	::getKeySize, cAlgBfish256	::getBlockSize },
			{ bcsaBFish448,		cAlgBfish448	::createAlg, cAlgBfish448	::getKeySize, cAlgBfish448	::getBlockSize },
			{ bcsaTFISH,		cAlgTFish		::createAlg, cAlgTFish		::getKeySize, cAlgTFish		::getBlockSize },
			{ pgpsaTFISH,		cAlgTFish		::createAlg, cAlgTFish		::getKeySize, cAlgTFish		::getBlockSize },
			{ bcsaGOST,			cAlgGOST		::createAlg, cAlgGOST		::getKeySize, cAlgGOST		::getBlockSize },
			{ bcsaRIJN,			cAlgRIJN		::createAlg, cAlgRIJN		::getKeySize, cAlgRIJN		::getBlockSize },
			{ pgpsaAES_128,		cAlgAES128		::createAlg, cAlgAES128		::getKeySize, cAlgAES128	::getBlockSize },
			{ pgpsaAES_192,		cAlgAES192		::createAlg, cAlgAES192		::getKeySize, cAlgAES192	::getBlockSize },
			{ pgpsaAES_256,		cAlgRIJN		::createAlg, cAlgRIJN		::getKeySize, cAlgRIJN		::getBlockSize },
			{ bcsaSERP,			cAlgSerpent		::createAlg, cAlgSerpent	::getKeySize, cAlgSerpent	::getBlockSize },
			{ bcsaDES,			cAlgDes			::createAlg, cAlgDes		::getKeySize, cAlgDes		::getBlockSize },
			{ pgpsa40BitRC2,	cAlgRC2_40		::createAlg, cAlgRC2_40		::getKeySize, cAlgRC2_40	::getBlockSize },
			{ pgpsa128BitRC2,	cAlgRC2_128		::createAlg, cAlgRC2_128	::getKeySize, cAlgRC2_128	::getBlockSize },
		};

//
//	See enums at pktdefs.h
//
static int IDsTab[] = {
	pgpsaIDEA,
	pgpsaTripleDES,
	pgpsaCAST5,
	pgpsaBlowfish,
//	pgpsaAES_256,
	bcsaBFish,
	bcsaBFish448,
	bcsaTFISH,
	bcsaGOST,
	bcsaRIJN,
	bcsaSERP,
	pgpsa40BitRC2,
	pgpsa128BitRC2,
	pgpsaPlaintext
};

const char *sa_getSymmetricAlgName( BYTE algID )
{
	if ( algID < bcsaMinAlgID )
		return PKT_GetSymmetricAlgName( algID );

	switch( algID )
	{
		case bcsaBFish		: return "Blowfish 256";
		case bcsaBFish448	: return "Blowfish 448";
		case bcsaTFISH		: return cAlgTFish	::getDisplayName(); //"TWOFISH";
		case bcsaGOST		: return cAlgGOST	::getDisplayName(); // "GOST";
		case bcsaRIJN		: return cAlgRIJN	::getDisplayName(); //"RIJNDAEL";
		case bcsaSERP		: return cAlgSerpent::getDisplayName();
		case bcsaDES		: return cAlgDes	::getDisplayName();
		default : return NULL;
	}
}

int sa_getIDsOfAvailableAlgAlgorithms( int *pIDsCount, int **ppIDsTab )
{
	if ( pIDsCount != NULL )
		*pIDsCount = sizeof( IDsTab ) / sizeof( *IDsTab );

	if ( ppIDsTab != NULL )
		*ppIDsTab = IDsTab;

	return sae_ok;
}

int sa_createAlgorithm( HSA *pHSA, int algID, BYTE *keyBuff, int keyBuffSize )
{
	int q = sizeof( algTbl ) / sizeof( algTbl[0] );

	while ( q-- )
	{
		if ( algTbl[q].algID == algID )
		{
			*pHSA = algTbl[q].createFunc( keyBuff, keyBuffSize );
			return sae_ok;
		}
	}

	return sae_invalidAlgorithmID;
}

int sa_getKeySize( int algID, int *pMax )
{
	int q = sizeof( algTbl ) / sizeof( algTbl[0] );

	while ( q-- )
	{
		if ( algTbl[q].algID == algID )
			return algTbl[q].getKeySizeFunc( pMax );
	}

	return 0;
}

int sa_getBlockSize( int algID )
{
	int q = sizeof( algTbl ) / sizeof( algTbl[0] );

	while ( q-- )
	{
		if ( algTbl[q].algID == algID )
			return algTbl[q].getBlockSizeFunc();
	}

	return 0;
}

bool sa_isValidID( int algID )
{
	return ( sa_getBlockSize( algID ) != 0 ) ||
			( algID == pgpsaPlaintext );
}


int sa_encrypt( cSymAlg *sa, BYTE *outBf, const BYTE *inBf, int bfSize ) { return sa->encryptECB( inBf, outBf, bfSize ); }
int sa_decrypt( cSymAlg *sa, BYTE *outBf, const BYTE *inBf, int bfSize ) { return sa->decryptECB( inBf, outBf, bfSize ); }

//
// Switch on BestCrypt driver CBC mode compatibility.
//
void sa_setBCDriverCompatible( cSymAlg *sa, cSymAlg::eCompatibleType eType ) { sa->setBCDriverCompatible( eType ); }

int sa_encryptCBC( cSymAlg *sa, const BYTE *sync, BYTE *outBf, const BYTE *inBf, int bfSize ) { return sa->m_encryptCBC( sa, sync, inBf, outBf, bfSize ); }
int sa_decryptCBC( cSymAlg *sa, const BYTE *sync, BYTE *outBf, const BYTE *inBf, int bfSize ) { return sa->m_decryptCBC( sa, sync, inBf, outBf, bfSize ); }

int sa_initCFB( cSymAlg *sa, const BYTE *iv )	{ return sa->initCFB( iv ); }
int sa_syncCFB( cSymAlg *sa )					{ return sa->syncCFB();		}

int sa_encryptCFB( cSymAlg *sa, BYTE *outBf, const BYTE *inBf, int bfSize ) { return sa->encryptCFB( inBf, outBf, bfSize ); }
int sa_decryptCFB( cSymAlg *sa, BYTE *outBf, const BYTE *inBf, int bfSize ) { return sa->decryptCFB( inBf, outBf, bfSize ); }

void sa_free( cSymAlg *sa ) { delete sa; }

int sa_getBlockSize( cSymAlg *sa ) 
{
	int blockSize;
	int keySize;

	if (!sa->getAlgConstants( &blockSize, &keySize ))
		return 0;

	return blockSize;
}
